from collections import namedtuple

import networkx as nx

Street = namedtuple('Street', ['u', 'v', 'distance', 'consumption'])
Node = namedtuple('Node', ['label', 'charging_coeff'], defaults=(None, None))

edge_case = {
    'b_0': 0,
    'b_t': 0,
    'U': 4,
    'nodes': [
        Node('s', charging_coeff=1),
        Node('a', charging_coeff=2),
        Node('t'),
    ],
    'edges': [
        Street(0, 1, distance=1, consumption=1),
        Street(0, 2, distance=1, consumption=4),
        Street(1, 2, distance=1, consumption=1),
    ]
}


def get_graph(config):
    G = nx.Graph()

    for node_id, node in enumerate(config['nodes']):
        G.add_node(node_id, label=node.label, c=node.charging_coeff)

    for edge in config['edges']:
        G.add_edge(edge.u, edge.v, weight=edge.distance, c=edge.consumption)

    return G
